@@ -15,7 +15,6 @@ nanotest(inherits(n$socket, "nano"))
 nanotest(is_nano(n))
 n$newmethod <- "doesnotwork"
 nanotestn(n$newmethod)
-
 nanotest(is.integer(attr(n$socket, "id")))
 nanotest(n$socket$state == "opened")
 nanotest(n$socket$protocol == "pair")
@@ -28,7 +27,6 @@ nanotest(n$getopt("recv-buffer") == 8L)
 nanotestz(n$setopt("socket-name", "nano"))
 nanotest(n$getopt("socket-name") == "nano")
 nanotestw(n$setopt("socket-name", NULL) == 3L)
-
 n$listener[[1]]
 nanotest(inherits(n$listener[[1]], "nanoListener"))
 nanotest(n$listener[[1]]$url == "inproc://nanonext")
@@ -43,7 +41,6 @@ nanotestw(n$listener_setopt("false", TRUE) == 9L)
 nanotesterr(n$listener_setopt("false", list()), "type")
 nanotestz(n$listener_start())
 nanotest(n$listener[[1]]$state == "started")
-
 n1$dialer[[1]]
 nanotest(inherits(n1$dialer[[1]], "nanoDialer"))
 nanotest(n1$dialer[[1]]$url == "inproc://nanonext")
@@ -92,7 +89,6 @@ nanotest(is_aio(saio))
 nanotest(is.logical(unresolved(saio)))
 nanotestnn(raio$raw)
 nanotest(identical(unserialize(call_aio(raio)$raw), raio$data))
-
 msg <- n1$recv_aio(mode = "numer", keep.raw = TRUE, timeout = 500)
 nanotestn(stop_aio(msg))
 nanotestn(stop_aio(n))
@@ -145,7 +141,6 @@ nanotest(inherits(n$dialer[[1L]], "nanoDialer"))
 nanotestz(n$listen(url = "inproc://three", autostart = FALSE))
 nanotestz(n$listener_start())
 nanotest(inherits(n$listener[[2L]], "nanoListener"))
-
 nanotestz(close(n$listener[[1]]))
 nanotestw(close(n$listener[[1]]) == 12L)
 nanotestz(close(n1$dialer[[1]]))
@@ -209,7 +204,7 @@ nanotestz(close(ctx))
 nanotestz(close(rep))
 
 pub <- nano("pub", listen = "inproc://ps")
-sub <- nano("sub", dial = "inproc://ps")
+sub <- nano("sub", dial = "inproc://ps", autostart = NA)
 nanotestz(sub$setopt(opt = "sub:prefnew", value = FALSE))
 nanotest(!sub$getopt(opt = "sub:prefnew"))
 nanotestw(sub$setopt(opt = "false", value = 100) == 9L)
@@ -217,14 +212,12 @@ nanotesterr(sub$getopt(opt = "false"), 9)
 nanotesterr(sub$setopt(opt = "false", value = list()), "type")
 nanotestz(sub$subscribe("test"))
 nanotestz(subscribe(sub$socket, NULL))
-nanotestz(unsubscribe(sub$socket, NULL))
 nanotestz(sub$unsubscribe("test"))
 nanotestnn(sub$context_open())
 nanotest(inherits(sub$context, "nanoContext"))
 nanotestz(sub$subscribe(12))
 nanotestz(sub$unsubscribe(12))
 nanotestz(sub$subscribe(NULL))
-nanotestz(sub$unsubscribe(NULL))
 nanotestz(sub$context_close())
 nanotestn(sub$context)
 nanotestz(sub$close())
@@ -246,6 +239,19 @@ nanotestz(surv$close())
 nanotestz(resp$close())
 nanotest(is_error_value(resp$recv(keep.raw = TRUE)$raw))
 
+nanotest(inherits(bus <- socket(protocol = "bus"), "nanoSocket"))
+nanotest(inherits(push <- socket(protocol = "push"), "nanoSocket"))
+nanotest(inherits(pull <- socket(protocol = "pull"), "nanoSocket"))
+nanotest(inherits(survey <- nano(protocol = "surveyor"), "nanoObject"))
+nanotest(inherits(respond <- nano(protocol = "respondent"), "nanoObject"))
+nanotest(is_nano(bus))
+nanotestz(close(bus))
+nanotestz(close(push))
+nanotestz(close(pull))
+nanotestz(survey$close())
+nanotestz(respond$close())
+nanotesterr(socket(protocol = "newprotocol"), "protocol")
+
 nanotestnn(ncurl("http://www.cam.ac.uk/"))
 nanotestnn(ncurl("http://www.cam.ac.uk/", follow = TRUE))
 nanotestnn(ncurl("http://httpbin.org/post", convert = FALSE, method = "POST", headers = c(`Content-Type` = "text/plain"), data = "test", response = "server"))
@@ -268,23 +274,19 @@ nanotest(is_error_value(ncurl("http", async = TRUE)$data))
 haio <- ncurl("https://i.i", async = TRUE)
 nanotest(is_error_value(call_aio(haio)$raw))
 haio$data
+sess <- tryCatch(ncurl_session("https://httpbin.org/post", method = "POST", headers = c(`Content-Type` = "text/plain"), data = "test", response = "server"), error = identity)
+nanotestnn(sess)
+nanotest(if (!inherits(sess, "error")) length(transact(sess)) == 4L else TRUE)
+sess <- tryCatch(ncurl_session("https://httpbin.org/post", convert = FALSE, method = "POST", headers = list(`Content-Type` = "text/plain"), response = list("Date", "Server")), error = identity)
+nanotestnn(sess)
+nanotest(if (!inherits(sess, "error")) length(transact(sess)) == 4L else TRUE)
+nanotest(if (!inherits(sess, "error")) close(sess) == 0L else TRUE)
+nanotesterr(transact(sess), "ncurlSession")
+nanotesterr(ncurl_session("https://i.i"))
 nanotesterr(stream(dial = "wss://127.0.0.1:5555"))
 nanotesterr(stream(listen = "errorValue3"), 3)
 nanotesterr(stream(), "specify")
 
-nanotest(inherits(bus <- socket(protocol = "bus"), "nanoSocket"))
-nanotest(inherits(push <- socket(protocol = "push"), "nanoSocket"))
-nanotest(inherits(pull <- socket(protocol = "pull"), "nanoSocket"))
-nanotest(inherits(survey <- nano(protocol = "surveyor"), "nanoObject"))
-nanotest(inherits(respond <- nano(protocol = "respondent"), "nanoObject"))
-nanotest(is_nano(bus))
-nanotestz(close(bus))
-nanotestz(close(push))
-nanotestz(close(pull))
-nanotestz(survey$close())
-nanotestz(respond$close())
-nanotesterr(socket(protocol = "newprotocol"), "protocol")
-
 nanotest(is.character(ver <- nng_version()) && length(ver) == 2L)
 nanotest(nng_error(8L) == "Try again")
 nanotest(is_nul_byte(as.raw(0L)))
@@ -298,7 +300,6 @@ nanotestn(msleep("a"))
 nanotest(is.double(random()))
 nanotest(length(random(2)) == 2L)
 nanotesterr(random("test"), "integer")
-nanotestn(suppressMessages(nano_init("test")))
 nanotesterr(device(push, pull), 7)
 nanotesterr(device(ctx, push), "s1")
 nanotesterr(device(push, ctx), "s2")
@@ -318,13 +319,17 @@ nanotesterr(subscribe(fakectx, NULL), "valid")
 nanotesterr(close(fakectx), "valid Context")
 fakestream <- `class<-`("test", "nanoStream")
 fakestream
+fakesession <- `class<-`("test", "ncurlSession")
+fakesession
+nanotesterr(transact(fakesession), "valid")
+nanotesterr(close(fakesession), "valid")
 nanotesterr(send(fakestream, "test"), "valid")
 nanotesterr(send_aio(fakestream, "test"), "valid")
 nanotesterr(recv(fakestream), "valid")
 nanotesterr(recv_aio(fakestream), "valid")
 nanotesterr(setopt(fakestream, opt = "test", value = "test"), "valid")
 nanotesterr(getopt(fakestream, opt = "test"), "valid")
-nanotesterr(close(fakestream), "valid Stream")
+nanotesterr(close(fakestream), "active Stream")
 fakedial <- `class<-`("test", "nanoDialer")
 nanotesterr(start(fakedial), "valid Dialer")
 nanotesterr(close(fakedial), "valid Dialer")
